@@ -7,7 +7,6 @@
 #'
 #' @usage
 #' get_wmts(x,
-#'          apikey = "ortho",
 #'          layer = "ORTHOIMAGERY.ORTHOPHOTOS",
 #'          zoom = 10L,
 #'          crs = 2154,
@@ -17,8 +16,6 @@
 #'
 #' @param x Object of class `sf` or `sfc`. Needs to be located in
 #' France.
-#' @param apikey `character`; API key from `get_apikeys()` or directly
-#' from [IGN website](https://geoservices.ign.fr/services-web-experts).
 #' @param layer `character`; layer name from
 #' `get_layers_metadata(apikey, "wms")` or directly from
 #' [IGN website](https://geoservices.ign.fr/services-web-experts).
@@ -26,7 +23,7 @@
 #' map tiles covers a large geographical area. In other words, the smaller
 #' the zoom level, the less precise the resolution. For conversion between zoom
 #' level and resolution see
-#' [WMTS IGN Documentation](https://geoservices.ign.fr/documentation/services/api-et-services-ogc/images-tuilees-wmts-ogc)
+#' [WMTS IGN Documentation](https://geoservices.ign.fr/documentation/services/services-geoplateforme/diffusion#70062)
 #' @param crs `numeric`, `character`, or object of class `sf` or `sfc`.
 #' It is set to EPSG:2154 by default. See [sf::st_crs()] for more detail.
 #' @param filename `character` or `NULL`; filename or a open connection for
@@ -50,10 +47,31 @@
 #'
 #'@examples
 #' \dontrun{
-#' TO-DO
+#' library(sf)
+#' library(tmap)
+#'
+#' penmarch <- read_sf(system.file("extdata/penmarch.shp", package = "happign"))
+#'
+#' # Get orthophoto
+#' layers <- get_layers_metadata("wmts", "ortho")$Identifier
+#' ortho <- get_wmts(penmarch, layer = layers[1], zoom = 21)
+#' plotRGB(ortho)
+#'
+#' # Get all available irc images
+#' layers <- get_layers_metadata("wmts", "orthohisto")$Identifier
+#' irc_names <- grep("irc", layers, value = TRUE, ignore.case = TRUE)
+#'
+#' irc <- lapply(irc_names, function(x) get_wmts(penmarch, layer = x, zoom = 18)) |>
+#'    setNames(irc_names)
+#'
+#' # remove empty layer (e.g. only NA)
+#' irc <- Filter(function(x) !all(is.na(values(x))), irc)
+#'
+#' # plot
+#' all_plots <- lapply(irc, plotRGB)
+#'
 #'}
 get_wmts <- function(x,
-                     apikey = "ortho",
                      layer = "ORTHOIMAGERY.ORTHOPHOTOS",
                      zoom = 10L,
                      crs = 2154,
@@ -70,20 +88,11 @@ get_wmts <- function(x,
    # interactive mode ----
    # if TRUE menu ask for apikey and layer name
    if (interactive){
-      choice <- interactive_mode()
-      apikey <- choice$apikey
+      choice <- interactive_mode("wmts")
       layer <- choice$layer
    }
 
    # check other input ----
-   # apikey
-   is_apikey <- apikey %in% get_apikeys()
-   is_personal_key <- grepl("^[[:alnum:]]{24}$", apikey)
-   if (!any(is_apikey, is_personal_key)) {
-      stop("`apikey` must be a character from `get_apikey()` or a personal key.",
-           call. = F)
-   }
-
    # layer
    if (!inherits(layer, "character")) {
       stop("`layer` must be of class character.", call. = F)
@@ -97,6 +106,12 @@ get_wmts <- function(x,
       zoom <- as.integer(zoom)
    }
 
+   # if no filename provided, layer is used by removing non alphanum character
+   if (is.null(filename)){
+      filename <- gsub("[^[:alnum:]]", "_", layer)
+      filename <- paste0(filename, ".tif") # Save as geotiff by default
+   }
+
    # overwrite ----
    # if filename exist and overwrite is set to FALSE, raster is loaded
    if (file.exists(filename) && !overwrite) {
@@ -108,10 +123,9 @@ get_wmts <- function(x,
 
    # prepare param for gdal warp ----
    bbox <- st_transform(x, crs) |> st_bbox()
-   crs <- paste0("EPSG:", st_crs(bbox)$epsg)
+   crs <- st_crs(bbox)$srid
 
-   url <- sprintf("WMTS:https://wxs.ign.fr/%s/geoportail/wmts?service=WMTS&version=1.0.0&request=GetCapabilities",
-                  apikey)
+   url <- sprintf("WMTS:https://data.geopf.fr/wmts?SERVICE=WMTS&VERSION=1.0.0&REQUEST=GetCapabilities")
 
    options <- c("-te", bbox$xmin, bbox$ymin, bbox$xmax, bbox$ymax,
                 "-te_srs", crs,
